@@ -94,8 +94,8 @@ static struct ln_parser_info parser_lookup_table[] = {
 	PARSER_ENTRY_NO_DATA("cee-syslog", CEESyslog, 4),
 	PARSER_ENTRY_NO_DATA("mac48", MAC48, 16),
 	PARSER_ENTRY_NO_DATA("cef", CEF, 4),
-	PARSER_ENTRY_NO_DATA("checkpoint-lea", CheckpointLEA, 4),
 	PARSER_ENTRY_NO_DATA("v2-iptables", v2IPTables, 4),
+	PARSER_ENTRY("checkpoint-lea", CheckpointLEA, 4),
 	PARSER_ENTRY("string-to", StringTo, 32),
 	PARSER_ENTRY("char-to", CharTo, 32),
 	PARSER_ENTRY("char-sep", CharSeparated, 32),
@@ -206,6 +206,7 @@ ln_newParser(ln_ctx ctx,
 	struct ln_type_pdag *custType = NULL;
 	const char *name = NULL;
 	const char *textconf = json_object_to_json_string(prscnf);
+	int assignedPrio = DFLT_USR_PARSER_PRIO;
 	int parserPrio;
 
 	json_object_object_get_ex(prscnf, "type", &json);
@@ -240,8 +241,9 @@ ln_newParser(ln_ctx ctx,
 	}
 
 	json_object_object_get_ex(prscnf, "priority", &json);
-	const int assignedPrio = (json == NULL) ? DFLT_USR_PARSER_PRIO :
-						  json_object_get_int(json);
+	if(json != NULL) {
+		assignedPrio = json_object_get_int(json);
+	}
 	LN_DBGPRINTF(ctx, "assigned priority is %d", assignedPrio);
 
 	/* we need to remove already processed items from the config, so
@@ -265,7 +267,7 @@ ln_newParser(ln_ctx ctx,
 	node->prsid = prsid;
 	node->conf = strdup(textconf);
 	if(prsid == PRS_CUSTOM_TYPE) {
-		node->custType = custType;
+		node->custTypeIdx = custType - ctx->type_pdags;
 	} else {
 		if(parser_lookup_table[prsid].construct != NULL) {
 			parser_lookup_table[prsid].construct(ctx, prscnf, &node->parser_data);
@@ -404,7 +406,8 @@ for(int i = 0 ; i < dag->nparsers ; ++i) { /* TODO: remove when confident enough
 		ln_parser_t *prs = dag->parsers+i;
 		LN_DBGPRINTF(dag->ctx, "optimizing %p: field %d type '%s', name '%s': '%s':",
 			prs->node, i, parserName(prs->prsid), prs->name,
-			(prs->prsid == PRS_LITERAL) ?  ln_DataForDisplayLiteral(dag->ctx, prs->parser_data) : "UNKNOWN");
+			(prs->prsid == PRS_LITERAL) ?  ln_DataForDisplayLiteral(dag->ctx, prs->parser_data)
+				: "UNKNOWN");
 
 		optLitPathCompact(ctx, prs);
 
@@ -837,6 +840,7 @@ ln_pdagAddParserInstance(ln_ctx ctx,
 	struct ln_pdag **nextnode)
 {
 	int r;
+	ln_parser_t *newtab;
 	LN_DBGPRINTF(ctx, "ln_pdagAddParserInstance: %s, nextnode %p",
 		json_object_to_json_string(prscnf), *nextnode);
 	ln_parser_t *const parser = ln_newParser(ctx, prscnf);
@@ -869,8 +873,7 @@ ln_pdagAddParserInstance(ln_ctx ctx,
 		(*nextnode)->refcnt++;
 	}
 	parser->node = *nextnode;
-	ln_parser_t *const newtab
-		= realloc(pdag->parsers, (pdag->nparsers+1) * sizeof(ln_parser_t));
+	newtab = realloc(pdag->parsers, (pdag->nparsers+1) * sizeof(ln_parser_t));
 	CHKN(newtab);
 	pdag->parsers = newtab;
 	memcpy(pdag->parsers+pdag->nparsers, parser, sizeof(ln_parser_t));
@@ -1020,7 +1023,8 @@ for(int i = 0 ; i < dag->nparsers ; ++i) {
 		LN_DBGPRINTF(dag->ctx, "%sfield type '%s', name '%s': '%s':", indent,
 			parserName(prs->prsid),
 			dag->parsers[i].name,
-			(prs->prsid == PRS_LITERAL) ?  ln_DataForDisplayLiteral(dag->ctx, prs->parser_data) : "UNKNOWN");
+			(prs->prsid == PRS_LITERAL) ?  ln_DataForDisplayLiteral(dag->ctx, prs->parser_data) :
+				"UNKNOWN");
 		if(prs->prsid == PRS_REPEAT) {
 			struct data_Repeat *const data = (struct data_Repeat*) prs->parser_data;
 			LN_DBGPRINTF(dag->ctx, "%sparser:", indent);
@@ -1433,10 +1437,10 @@ tryParser(npb_t *const __restrict__ npb,
 	if(prs->prsid == PRS_CUSTOM_TYPE) {
 		if(*value == NULL)
 			*value = json_object_new_object();
-		LN_DBGPRINTF(dag->ctx, "calling custom parser '%s'", prs->custType->name);
-		r = ln_normalizeRec(npb, prs->custType->pdag, *offs, 1, *value, &endNode);
+		LN_DBGPRINTF(dag->ctx, "calling custom parser '%s'", dag->ctx->type_pdags[prs->custTypeIdx].name);
+		r = ln_normalizeRec(npb, dag->ctx->type_pdags[prs->custTypeIdx].pdag, *offs, 1, *value, &endNode);
 		LN_DBGPRINTF(dag->ctx, "called CUSTOM PARSER '%s', result %d, "
-			"offs %zd, *pParsed %zd", prs->custType->name, r, *offs, *pParsed);
+			"offs %zd, *pParsed %zd", dag->ctx->type_pdags[prs->custTypeIdx].name, r, *offs, *pParsed);
 		*pParsed = npb->parsedTo - *offs;
 		#ifdef	ADVANCED_STATS
 		es_addBuf(&npb->astats.exec_path, hdr, lenhdr);
@@ -1618,6 +1622,7 @@ int
 ln_normalize(ln_ctx ctx, const char *str, const size_t strLen, struct json_object **json_p)
 {
 	int r;
+	struct ln_pdag *endNode = NULL;
 	/* old cruft */
 	if(ctx->version == 1) {
 		r = ln_v1_normalize(ctx, str, strLen, json_p);
@@ -1625,7 +1630,6 @@ ln_normalize(ln_ctx ctx, const char *str, const size_t strLen, struct json_objec
 	}
 	/* end old cruft */
 
-	struct ln_pdag *endNode = NULL;
 	npb_t npb;
 	memset(&npb, 0, sizeof(npb));
 	npb.ctx = ctx;
