@@ -1,13 +1,6 @@
-
-uname -a | grep "SunOS.*5.10"
-if [ $? -eq 0 ] ; then
-   echo platform: `uname -a`
-   echo This looks like solaris 10, we disable known-failing tests to
-   echo permit OpenCSW to build packages. However, this are real failurs
-   echo and so a fix should be done as soon as time permits.
-   exit 77
-fi
+#!/bin/bash
 . $srcdir/exec.sh
+no_solaris10
 
 test_def $0 "multiple formats including string (see also: rule_last_str_short.sh)"
 add_rule 'version=2'
